==> igniteui-react-charts-16.6.8.tgz: package/ES2015/ChaikinOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { ChaikinOscillatorIndicatorStrategy } from "./ChaikinOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core/ES2015/type";
/**
 * @hidden
 */
export class ChaikinOscillatorIndicator extends StrategyBasedIndicator {
    get_p5() {
        return new ChaikinOscillatorIndicatorStrategy();
    }
    get p5() {
        return this.get_p5();
    }
    get_qi() {
        return ChaikinOscillatorIndicator.$;
    }
    get qi() {
        return this.get_qi();
    }
    get shortPeriod() {
        return typeGetValue(this.c(ChaikinOscillatorIndicator.qr));
    }
    set shortPeriod(a) {
        this.h(ChaikinOscillatorIndicator.qr, a);
    }
    qd() {
        return this.shortPeriod;
    }
    get longPeriod() {
        return typeGetValue(this.c(ChaikinOscillatorIndicator.qq));
    }
    set longPeriod(a) {
        this.h(ChaikinOscillatorIndicator.qq, a);
    }
    qa() {
        return this.longPeriod;
    }
}
ChaikinOscillatorIndicator.$t = markType(ChaikinOscillatorIndicator, 'ChaikinOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
ChaikinOscillatorIndicator.qr = StrategyBasedIndicator.qp(3, ChaikinOscillatorIndicator.$);
ChaikinOscillatorIndicator.qq = StrategyBasedIndicator.ql(10, ChaikinOscillatorIndicator.$);

==> igniteui-react-charts-16.11.1.tgz: package/ES2015/ChaikinOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { ChaikinOscillatorIndicatorStrategy } from "./ChaikinOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core/ES2015/type";
/**
 * @hidden
 */
export class ChaikinOscillatorIndicator extends StrategyBasedIndicator {
    get_qc() {
        return new ChaikinOscillatorIndicatorStrategy();
    }
    get qc() {
        return this.get_qc();
    }
    get_qp() {
        return ChaikinOscillatorIndicator.$;
    }
    get qp() {
        return this.get_qp();
    }
    get shortPeriod() {
        return typeGetValue(this.c(ChaikinOscillatorIndicator.qy));
    }
    set shortPeriod(a) {
        this.h(ChaikinOscillatorIndicator.qy, a);
    }
    qk() {
        return this.shortPeriod;
    }
    get longPeriod() {
        return typeGetValue(this.c(ChaikinOscillatorIndicator.qx));
    }
    set longPeriod(a) {
        this.h(ChaikinOscillatorIndicator.qx, a);
    }
    qh() {
        return this.longPeriod;
    }
}
ChaikinOscillatorIndicator.$t = markType(ChaikinOscillatorIndicator, 'ChaikinOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
ChaikinOscillatorIndicator.qy = StrategyBasedIndicator.qw(3, ChaikinOscillatorIndicator.$);
ChaikinOscillatorIndicator.qx = StrategyBasedIndicator.qs(10, ChaikinOscillatorIndicator.$);
